<?php
namespace FitGirlKiller;

class Poster {
    private $data;
    private $categories;
    private $upload_dir;

    public function __construct($data, $categories = []) {
        $this->data = $data;
        $this->categories = $categories;
        $this->upload_dir = wp_upload_dir();
    }

    public function create_post() {
        try {
            // Download and process images
            $images = $this->process_images();
            
            // Prepare post data
            $post_data = [
                'post_title'    => wp_strip_all_tags($this->data['title']),
                'post_content'  => $this->format_content($images),
                'post_status'   => 'publish',
                'post_author'   => get_current_user_id(),
                'post_type'     => 'post'
            ];

            // Create the post
            $post_id = wp_insert_post($post_data);

            if (!$post_id || is_wp_error($post_id)) {
                throw new \Exception('Failed to create post');
            }

            // Handle categories
            if (!empty($this->categories)) {
                $category_ids = [];
                
                foreach ($this->categories as $category_name) {
                    $category_name = trim($category_name);
                    if (empty($category_name)) continue;

                    // Try to find existing category
                    $category = get_term_by('name', $category_name, 'category');
                    
                    if ($category) {
                        $category_ids[] = (int)$category->term_id;
                    } else {
                        // Create new category
                        $new_category = wp_insert_term($category_name, 'category');
                        if (!is_wp_error($new_category)) {
                            $category_ids[] = (int)$new_category['term_id'];
                        }
                    }
                }

                // Set all categories at once
                if (!empty($category_ids)) {
                    wp_set_post_categories($post_id, $category_ids);
                }
            }

            // Set featured image
            if (!empty($images)) {
                set_post_thumbnail($post_id, $images[0]['id']);
            }

            return [
                'success' => true,
                'post_id' => $post_id,
                'permalink' => get_permalink($post_id)
            ];

        } catch (\Exception $e) {
            return [
                'success' => false,
                'error' => $e->getMessage()
            ];
        }
    }

    private function process_images() {
        $processed_images = [];
        
        foreach ($this->data['images'] as $image_url) {
            try {
                // Download image
                $response = wp_remote_get($image_url);
                
                if (is_wp_error($response)) {
                    continue;
                }

                $image_data = wp_remote_retrieve_body($response);
                
                // Generate unique filename
                $filename = sanitize_file_name(
                    pathinfo($image_url, PATHINFO_FILENAME) . 
                    '-' . uniqid() . 
                    '.' . pathinfo($image_url, PATHINFO_EXTENSION)
                );
                
                $upload_path = $this->upload_dir['path'] . '/' . $filename;
                
                // Save image
                file_put_contents($upload_path, $image_data);
                
                // Prepare attachment
                $attachment = [
                    'post_mime_type' => mime_content_type($upload_path),
                    'post_title'     => sanitize_file_name(pathinfo($filename, PATHINFO_FILENAME)),
                    'post_content'   => '',
                    'post_status'    => 'inherit'
                ];

                // Insert attachment
                $attach_id = wp_insert_attachment($attachment, $upload_path);
                
                if (!is_wp_error($attach_id)) {
                    // Generate metadata
                    require_once(ABSPATH . 'wp-admin/includes/image.php');
                    $attach_data = wp_generate_attachment_metadata($attach_id, $upload_path);
                    wp_update_attachment_metadata($attach_id, $attach_data);
                    
                    $processed_images[] = [
                        'id' => $attach_id,
                        'url' => wp_get_attachment_url($attach_id)
                    ];
                }
            } catch (\Exception $e) {
                // Log error but continue with other images
                error_log('FitGirl-Killer-By-WooPlug - Image processing error: ' . $e->getMessage());
                continue;
            }
        }
        
        return $processed_images;
    }

    private function format_content($images) {
        ob_start();
        ?>
        <div class="fitgirl-post">
            <style>
                /* Force center alignment for the post */
                .fitgirl-post {
                    max-width: 1200px !important;
                    margin-left: auto !important;
                    margin-right: auto !important;
                    float: none !important;
                    padding: 20px;
                    text-align: center;
                }

                /* Override any theme alignment */
                .entry-content,
                .post-content,
                article,
                .content-area,
                #primary,
                #main {
                    max-width: 100% !important;
                    margin-left: auto !important;
                    margin-right: auto !important;
                    float: none !important;
                    padding: 0 !important;
                }

                /* Center the entire post content */
                .fitgirl-post {
                    max-width: 1200px;
                    margin: 0 auto;
                    padding: 20px;
                    text-align: center;
                }

                .game-title {
                    text-align: center;
                    margin-bottom: 30px;
                }

                .game-screenshots-gallery {
                    display: flex;
                    flex-wrap: wrap;
                    justify-content: center;
                    gap: 20px;
                    margin: 30px 0;
                }

                .screenshot {
                    flex: 0 1 auto;
                    max-width: 100%;
                    text-align: center;
                }

                .screenshot img {
                    max-width: 100%;
                    height: auto;
                    border-radius: 8px;
                    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
                }

                .game-info, .repack-features, .game-description {
                    max-width: 800px;
                    margin: 30px auto;
                    text-align: left;
                }

                /* Modern Download Button */
                .download-section {
                    margin: 40px 0;
                    text-align: center;
                }

                .modern-download-button {
                    display: inline-flex;
                    align-items: center;
                    padding: 16px 32px;
                    background: linear-gradient(135deg, #6366f1, #4f46e5);
                    border-radius: 12px;
                    text-decoration: none;
                    color: white;
                    font-weight: 600;
                    font-size: 16px;
                    transition: all 0.3s ease;
                    box-shadow: 0 4px 15px rgba(99, 102, 241, 0.3);
                    position: relative;
                    overflow: hidden;
                }

                .modern-download-button:hover {
                    transform: translateY(-2px);
                    box-shadow: 0 6px 20px rgba(99, 102, 241, 0.4);
                }

                .modern-download-button:active {
                    transform: translateY(1px);
                }

                .button-content {
                    display: flex;
                    align-items: center;
                    gap: 12px;
                    position: relative;
                    z-index: 1;
                }

                .torrent-icon {
                    display: flex;
                    align-items: center;
                    color: white;
                    transition: transform 0.3s ease;
                }

                .modern-download-button:hover .torrent-icon {
                    transform: translateY(3px);
                    animation: bounce 1s infinite;
                }

                .button-text {
                    font-weight: 700;
                    letter-spacing: 0.5px;
                    text-transform: uppercase;
                }

                .modern-download-button::before {
                    content: '';
                    position: absolute;
                    top: 0;
                    left: 0;
                    width: 100%;
                    height: 100%;
                    background: linear-gradient(135deg, #4f46e5, #6366f1);
                    opacity: 0;
                    transition: opacity 0.3s ease;
                }

                .modern-download-button:hover::before {
                    opacity: 1;
                }

                @keyframes bounce {
                    0%, 100% {
                        transform: translateY(0);
                    }
                    50% {
                        transform: translateY(3px);
                    }
                }

                @media (max-width: 768px) {
                    .modern-download-button {
                        padding: 14px 28px;
                        font-size: 14px;
                    }
                }

                .sponsored-section {
                    margin-top: 40px;
                    padding: 20px;
                    background-color: #f7f7f7;
                    border: 1px solid #ddd;
                    border-radius: 10px;
                    box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
                }

                .sponsored-links {
                    margin-top: 20px;
                }

                .sponsored-link {
                    margin-bottom: 10px;
                }

                .sponsored-link a {
                    text-decoration: none;
                    color: #337ab7;
                }

                .sponsored-link a:hover {
                    color: #23527c;
                }
            </style>
            <h1 class="game-title"><?php echo esc_html($this->data['title']); ?></h1>
            <!-- Game Screenshots Gallery - Right after title -->
            <?php if (!empty($images)): ?>
                <div class="game-screenshots-gallery">
                    <?php foreach ($images as $image): ?>
                        <div class="screenshot">
                            <img src="<?php echo esc_url($image['url']); ?>" 
                                 alt="<?php echo esc_attr($this->data['title']); ?> screenshot"
                                 class="screenshot-img"
                                 loading="lazy">
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>

            <!-- Game Info Section -->
            <div class="game-info">
                <?php if (!empty($this->data['game_info'])): ?>
                    <div class="game-details">
                        <?php foreach ($this->data['game_info'] as $key => $value): 
                            if ($key !== 'repack_features'): // Skip repack features here
                        ?>
                            <div class="detail-item">
                                <span class="detail-label"><?php echo ucfirst(str_replace('_', ' ', $key)); ?>:</span>
                                <span class="detail-value"><?php echo esc_html($value); ?></span>
                            </div>
                        <?php 
                            endif;
                        endforeach; ?>
                    </div>
                <?php endif; ?>
            </div>

            <!-- Repack Features -->
            <?php if (!empty($this->data['game_info']['repack_features'])): ?>
                <div class="repack-features">
                    <?php echo wp_kses_post($this->data['game_info']['repack_features']); ?>
                </div>
            <?php endif; ?>

            <!-- Game Description -->
            <div class="game-description">
                <?php echo wp_kses_post($this->data['description']); ?>
            </div>

            <!-- Download Section -->
            <?php if (!empty($this->data['magnet_link'])): ?>
                <div class="download-section">
                    <a href="<?php echo esc_url($this->data['magnet_link']); ?>" 
                       class="modern-download-button"
                       onclick="window.location.href='<?php echo esc_js($this->data['magnet_link']); ?>'; return false;">
                        <div class="button-content">
                            <div class="torrent-icon">
                                <svg viewBox="0 0 512 512" width="24" height="24">
                                    <path fill="currentColor" d="M256 8C119 8 8 119 8 256s111 248 248 248 248-111 248-248S393 8 256 8zm0 448c-110.5 0-200-89.5-200-200S145.5 56 256 56s200 89.5 200 200-89.5 200-200 200zm-32-316v116h-67c-10.7 0-16 12.9-8.5 20.5l99 99c4.7 4.7 12.3 4.7 17 0l99-99c7.6-7.6 2.2-20.5-8.5-20.5h-67V140c0-6.6-5.4-12-12-12h-40c-6.6 0-12 5.4-12 12z"/>
                                </svg>
                            </div>
                            <span class="button-text">TORRENT DOWNLOAD</span>
                        </div>
                    </a>
                </div>
            <?php endif; ?>

            <!-- Sponsored Links Section -->
            <div class="sponsored-section">
                <h3>Sponsored Links</h3>
                <div class="sponsored-links">
                    <?php
                    $affiliate_links = [
                        ['url' => 'https://www.binance.com/activity/referral-entry/CPA?ref=CPA_0075AIVJX3', 'title' => 'Trade on Binance - Leading Cryptocurrency Exchange'],
                        ['url' => 'https://bingx.com/invite/4Y0CEV6B/', 'title' => 'Join BingX - Professional Crypto Trading Platform'],
                        ['url' => 'https://url.hk/i/en/9hdk3', 'title' => 'Exclusive Trading Opportunities']
                    ];
                    
                    // Randomize the order of links
                    shuffle($affiliate_links);
                    
                    foreach ($affiliate_links as $link): ?>
                        <div class="sponsored-link">
                            <a href="<?php echo esc_url($link['url']); ?>" target="_blank" rel="sponsored noopener">
                                <?php echo esc_html($link['title']); ?>
                            </a>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }
}