<?php
namespace FitGirlKiller;

class Scraper {
    private $url;
    private $dom;
    private $xpath;
    private $data = [];

    public function __construct($url) {
        $this->url = $url;
    }

    public function scrape() {
        try {
            $response = wp_remote_get($this->url);
            
            if (is_wp_error($response)) {
                throw new \Exception('Failed to fetch content: ' . $response->get_error_message());
            }

            if (wp_remote_retrieve_response_code($response) !== 200) {
                throw new \Exception('Invalid response code: ' . wp_remote_retrieve_response_code($response));
            }

            $html = wp_remote_retrieve_body($response);
            
            libxml_use_internal_errors(true);
            $this->dom = new \DOMDocument();
            $this->dom->loadHTML($html, LIBXML_NOERROR);
            $this->xpath = new \DOMXPath($this->dom);

            $this->extractTitle()
                 ->extractGameInfo()
                 ->extractDescription()
                 ->extractImages()
                 ->extractMagnetLink()
                 ->extractCategories();

            return $this->data;

        } catch (\Exception $e) {
            throw new \Exception('Scraping failed: ' . $e->getMessage());
        }
    }

    public function check_duplicate() {
        global $wpdb;
        
        // Clean the title for comparison
        $clean_title = sanitize_title($this->data['title']);
        
        // Check for exact title match
        $duplicate = $wpdb->get_var($wpdb->prepare(
            "SELECT ID FROM {$wpdb->posts} 
            WHERE post_title = %s 
            AND post_type = 'post' 
            AND post_status IN ('publish', 'draft')",
            $this->data['title']
        ));
        
        if ($duplicate) {
            return [
                'is_duplicate' => true,
                'post_id' => $duplicate,
                'post_url' => get_permalink($duplicate),
                'post_title' => $this->data['title']
            ];
        }
        
        return ['is_duplicate' => false];
    }

    private function extractTitle() {
        $title = $this->xpath->query('//h1[@class="entry-title"]')->item(0);
        if ($title) {
            $this->data['title'] = trim($title->textContent);
        } else {
            $this->data['title'] = '';
        }
        return $this;
    }

    private function extractGameInfo() {
        $content = $this->xpath->query('//div[contains(@class, "entry-content")]')->item(0);
        if ($content) {
            $gameInfo = [];
            
            // Extract all list items before the description
            $lists = $this->xpath->query('.//ul[1]/li', $content);
            foreach ($lists as $item) {
                $text = trim($item->textContent);
                if (strpos($text, 'Genre:') === 0) {
                    $gameInfo['genre'] = trim(substr($text, 6));
                } elseif (strpos($text, 'Developer:') === 0) {
                    $gameInfo['developer'] = trim(substr($text, 10));
                } elseif (strpos($text, 'Publisher:') === 0) {
                    $gameInfo['publisher'] = trim(substr($text, 10));
                } elseif (strpos($text, 'Size:') === 0) {
                    $gameInfo['size'] = trim(substr($text, 5));
                }
            }
            
            // Extract Repack Features
            $repackFeatures = '';
            $inRepackFeatures = false;
            $nodes = $this->xpath->query('.//h3|.//p|.//ul', $content);
            
            foreach ($nodes as $node) {
                $text = trim($node->textContent);
                
                // Check for Repack Features heading
                if ($node->nodeName === 'h3' && stripos($text, 'Repack Features') !== false) {
                    $inRepackFeatures = true;
                    $repackFeatures .= "<h3>Repack Features</h3>\n";
                    continue;
                }
                
                // If we're in Repack Features section
                if ($inRepackFeatures) {
                    // Stop when we hit another heading or specific keywords
                    if ($node->nodeName === 'h3' || 
                        stripos($text, 'Download') === 0 || 
                        stripos($text, 'Mirrors') === 0) {
                        break;
                    }
                    
                    // Handle different node types
                    if ($node->nodeName === 'ul') {
                        $repackFeatures .= "<ul>\n";
                        foreach ($node->childNodes as $li) {
                            if ($li->nodeName === 'li') {
                                $liText = trim($li->textContent);
                                if (!empty($liText)) {
                                    $repackFeatures .= "<li>" . htmlspecialchars($liText) . "</li>\n";
                                }
                            }
                        }
                        $repackFeatures .= "</ul>\n";
                    } elseif ($node->nodeName === 'p' && !empty($text)) {
                        $repackFeatures .= "<p>" . htmlspecialchars($text) . "</p>\n";
                    }
                }
            }
            
            $gameInfo['repack_features'] = trim($repackFeatures);
            $this->data['game_info'] = $gameInfo;
        }
        return $this;
    }

    private function extractDescription() {
        $content = $this->xpath->query('//div[contains(@class, "entry-content")]')->item(0);
        if ($content) {
            // Get all paragraphs after game info and before download section
            $description = '';
            $paragraphs = $this->xpath->query('.//p', $content);
            
            $captureDesc = false;
            foreach ($paragraphs as $p) {
                $text = trim($p->textContent);
                
                // Start capturing after game info
                if (strpos($text, 'Repack Features') !== false) {
                    $captureDesc = true;
                    continue;
                }
                
                // Stop capturing before download section
                if (strpos($text, 'Download') !== false || strpos($text, 'Mirrors') !== false) {
                    break;
                }
                
                if ($captureDesc && !empty($text)) {
                    $description .= "<p>{$text}</p>\n";
                }
            }
            
            $this->data['description'] = trim($description);
        } else {
            $this->data['description'] = '';
        }
        return $this;
    }

    private function extractImages() {
        $images = [];
        $imageNodes = $this->xpath->query('//div[contains(@class, "entry-content")]//img');
        
        foreach ($imageNodes as $img) {
            $src = $img->getAttribute('src');
            if ($src && !$this->isAdvertImage($src)) {
                $images[] = $src;
            }
        }
        
        $this->data['images'] = array_unique($images);
        return $this;
    }

    private function extractMagnetLink() {
        // Using the specific XPath for magnet links in FitGirl's site
        $magnetLink = $this->xpath->query('//div[contains(@class, "entry-content")]/ul[2]/li[1]/a[2]')->item(0);
        if ($magnetLink) {
            $this->data['magnet_link'] = $magnetLink->getAttribute('href');
        } else {
            $this->data['magnet_link'] = '';
        }
        return $this;
    }

    private function extractCategories() {
        $categories = [];
        
        // Find the genres section in the game info area
        $gameInfoNodes = $this->xpath->query('//div[contains(@class, "entry-content")]/p');
        
        foreach ($gameInfoNodes as $node) {
            $content = $node->textContent;
            if (strpos($content, 'Genre/Tags:') !== false) {
                // Extract everything after "Genre/Tags:" and before the next label
                if (preg_match('/Genre\/Tags:\s*([^:]+)(?=\s*[A-Za-z]+:|\s*$)/i', $content, $matches)) {
                    $genresText = trim($matches[1]);
                    // Split by comma and clean up
                    $rawCategories = explode(',', $genresText);
                    foreach ($rawCategories as $category) {
                        $category = trim($category);
                        if (!empty($category)) {
                            $categories[] = $category;
                        }
                    }
                    break; // Found what we need, exit loop
                }
            }
        }
        
        $this->data['categories'] = array_unique($categories);
        return $this;
    }

    private function isAdvertImage($src) {
        $adPatterns = [
            'advert',
            'banner',
            'sponsor',
            'ads',
            'pixel',
            'tracker'
        ];
        
        foreach ($adPatterns as $pattern) {
            if (stripos($src, $pattern) !== false) {
                return true;
            }
        }
        
        return false;
    }
}